# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-06-27 11:12
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100, verbose_name='Title')),
                ('slug', models.SlugField(max_length=100, unique=True)),
                ('is_active', models.BooleanField(default=True, verbose_name='Active')),
            ],
            options={
                'verbose_name': 'Category',
                'verbose_name_plural': 'Categories',
                'ordering': ('title',),
            },
        ),
        migrations.CreateModel(
            name='Link',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100, verbose_name='Title')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('href', models.URLField(verbose_name='Address')),
                ('is_active', models.BooleanField(default=True, verbose_name='Active')),
                ('category', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='simple_links.Category', verbose_name='Category')),
            ],
            options={
                'verbose_name': 'Link',
                'verbose_name_plural': 'Links',
                'ordering': ('category__title', 'title'),
            },
        ),
    ]



import re
from django import template
from simple_links.models import Link

register = template.Library()


class LinkListNode(template.Node):
    def __init__(self, category_slug, links_var_name, category_var_name):
        self.category_slug = category_slug
        self.links_var_name = links_var_name
        self.category_var_name = category_var_name

    def render(self, context):
        links = (Link.actives.filter(category__slug=self.category_slug)
            .select_related())

        if links:
            category = links[0].category
        else:
            category = None

        context[self.links_var_name] = links
        context[self.category_var_name] = category
        return ''


@register.tag('get_link_list')
def do_link_list(parser, token):
    """
    Using category slug as parameter returns a list of links and a
    category instance.

    Usage:: 

        {% load link_list %}
        {% get_link_list "blogroll" as links, category %}

        <h3>{{ category.title }}<h3>
        <ul>
        {% for link in links %}
            <li><a href="{{ link.get_absolute_url }}">
                {{ link.title }}</a></li>
        {% endfor %}
        </ul>
    """
    try:
        tag_name, arg = token.contents.split(None, 1)
    except ValueError:
        raise (template.TemplateSyntaxError("%r tag requires arguments"\
            % token.contents.split()[0]))

    m = re.search(r'"(.*?)" as (\w+),\s?(\w+)', arg)
    if not m:
        raise (template.TemplateSyntaxError("%r tag has invalid arguments"\
            % tag_name))

    category_slug, links_var, category_var = m.groups()
    return LinkListNode(category_slug, links_var, category_var)



from django.db import models
from django.utils.translation import ugettext_lazy as _

from simple_links import managers


class Category(models.Model):
    """
    A category for links.
    """
    title = models.CharField(_('Title'), max_length=100)
    slug = models.SlugField(max_length=100, unique=True)
    is_active = models.BooleanField(_('Active'), default=True)

    objects = models.Manager()
    actives = managers.CategoryActiveManager()

    class Meta:
        verbose_name = _('Category')
        verbose_name_plural = _('Categories')
        ordering = ('title', )

    def __unicode__(self):
        return self.title

    def __str__(self):
        return self.title


class Link(models.Model):
    """
    A link entry for blogrolls and similar.
    """
    category = models.ForeignKey(Category, verbose_name=_('Category'),
                                 on_delete=models.CASCADE)
    title = models.CharField(_(u'Title'), max_length=100)
    description = models.TextField(_(u'Description'), blank=True, null=True)
    href = models.URLField(_(u'Address'))
    is_active = models.BooleanField(_('Active'), default=True)

    objects = models.Manager()
    actives = managers.LinkActiveManager()

    class Meta:
        verbose_name = _('Link')
        verbose_name_plural = _('Links')
        ordering = ('category__title', 'title', )

    def __unicode__(self):
        return self.title

    def __str__(self):
        return self.title



from django.db import models


class CategoryActiveManager(models.Manager):
    def get_queryset(self, *args, **kwargs):
        """
        Filter a queryset with is_active as True.
        """
        qs = super(CategoryActiveManager, self).get_queryset(*args, **kwargs)
        return qs.filter(is_active=True)


class LinkActiveManager(CategoryActiveManager):
    def get_queryset(self, *args, **kwargs):
        """
        Filter a queryset with is_active of category model as True.
        """
        qs = super(LinkActiveManager, self).get_queryset(*args, **kwargs)
        return qs.filter(category__is_active=True)



from django.contrib import admin

from simple_links.models import Category, Link


class CategoryAdmin(admin.ModelAdmin):
    list_display = ('title', 'is_active', )
    search_fields = ('title', )
    prepopulated_fields = {'slug': ('title', )}


class LinkAdmin(admin.ModelAdmin):
    list_display = ('title', 'href', 'category', 'is_active', )
    search_fields = ('title', 'description', )
    list_filter = ('category', 'is_active', )


admin.site.register(Category, CategoryAdmin)
admin.site.register(Link, LinkAdmin)



from setuptools import setup
from simple_links import get_version


setup(
    name='django-simple-links',
    version=get_version(),
    license='GNU Lesser General Public License (LGPL), Version 3',

    description='Simple bookmarking application for Django projects',
    long_description=('Simple Links is a pluggable app that '
                      'that lets you easily add links in your Django project.'),
    keywords='django apps links bookmark',

    author='Klaus Laube',
    author_email='kplaube@gmail.com',

    url='https://github.com/kplaube/django-simple-links',
    packages=['simple_links',
              'simple_links.migrations',
              'simple_links.templatetags', ],
    include_package_data=True,
    zip_safe=False,

    classifiers=[
        'Environment :: Plugins',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
